.. _pecan_configuration:

:mod:`pecan.configuration` -- Pecan Configuration Engine
========================================================

The :mod:`pecan.configuration` module provides an implementation of a
Python-based configuration engine for Pecan applications.

.. automodule:: pecan.configuration
  :members:
  :show-inheritance: